==> gitlab_17.0.8.orig.tar.bz2: gitlab-foss-v17.0.8/app/assets/javascripts/projects/settings_service_desk/index.js <==
import { GlToast } from '@gitlab/ui';
import Vue from 'vue';
import { parseBoolean } from '~/lib/utils/common_utils';
import ServiceDeskRoot from './components/service_desk_root.vue';

Vue.use(GlToast);

export default () => {
  const el = document.querySelector('.js-service-desk-setting-root');

  if (!el) {
    return false;
  }

  const {
    serviceDeskEmail,
    serviceDeskEmailEnabled,
    enabled,
    issueTrackerEnabled,
    endpoint,
    incomingEmail,
    outgoingName,
    projectKey,
    reopenIssueOnExternalParticipantNote,
    addExternalParticipantsFromCc,
    selectedTemplate,
    selectedFileTemplateProjectId,
    templates,
    publicProject,
    customEmailEndpoint,
  } = el.dataset;

  return new Vue({
    el,
    provide: {
      serviceDeskEmail,
      serviceDeskEmailEnabled: parseBoolean(serviceDeskEmailEnabled),
      endpoint,
      initialIncomingEmail: incomingEmail,
      initialIsEnabled: parseBoolean(enabled),
      isIssueTrackerEnabled: parseBoolean(issueTrackerEnabled),
      outgoingName,
      projectKey,
      reopenIssueOnExternalParticipantNote: parseBoolean(reopenIssueOnExternalParticipantNote),
      addExternalParticipantsFromCc: parseBoolean(addExternalParticipantsFromCc),
      selectedTemplate,
      selectedFileTemplateProjectId: parseInt(selectedFileTemplateProjectId, 10) || null,
      templates: JSON.parse(templates),
      publicProject: parseBoolean(publicProject),
      customEmailEndpoint,
    },
    render: (createElement) => createElement(ServiceDeskRoot),
  });
};

==> gitlab_17.6.5.orig.tar.bz2: gitlab-foss-v17.6.5/app/assets/javascripts/projects/settings_service_desk/index.js <==
import { GlToast } from '@gitlab/ui';
import Vue from 'vue';
import { parseBoolean } from '~/lib/utils/common_utils';
import ServiceDeskRoot from './components/service_desk_root.vue';

Vue.use(GlToast);

export default () => {
  const el = document.querySelector('.js-service-desk-setting-root');

  if (!el) {
    return false;
  }

  const {
    serviceDeskEmail,
    serviceDeskEmailEnabled,
    enabled,
    issueTrackerEnabled,
    endpoint,
    incomingEmail,
    outgoingName,
    projectKey,
    ticketsConfidentialByDefault,
    reopenIssueOnExternalParticipantNote,
    addExternalParticipantsFromCc,
    selectedTemplate,
    selectedFileTemplateProjectId,
    templates,
    publicProject,
    customEmailEndpoint,
  } = el.dataset;

  return new Vue({
    el,
    provide: {
      serviceDeskEmail,
      serviceDeskEmailEnabled: parseBoolean(serviceDeskEmailEnabled),
      endpoint,
      initialIncomingEmail: incomingEmail,
      initialIsEnabled: parseBoolean(enabled),
      isIssueTrackerEnabled: parseBoolean(issueTrackerEnabled),
      outgoingName,
      projectKey,
      areTicketsConfidentialByDefault: parseBoolean(ticketsConfidentialByDefault),
      reopenIssueOnExternalParticipantNote: parseBoolean(reopenIssueOnExternalParticipantNote),
      addExternalParticipantsFromCc: parseBoolean(addExternalParticipantsFromCc),
      selectedTemplate,
      selectedFileTemplateProjectId: parseInt(selectedFileTemplateProjectId, 10) || null,
      templates: JSON.parse(templates),
      publicProject: parseBoolean(publicProject),
      customEmailEndpoint,
    },
    render: (createElement) => createElement(ServiceDeskRoot),
  });
};
